"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var path = require("path");
var mkdirp_1 = require("mkdirp");
var fs = require("fs");
var fs_extra_1 = require("fs-extra");
var lodash_1 = require("lodash");
var paths_1 = require("../paths");
var config = require("../config");
var AddResponseType;
(function (AddResponseType) {
    AddResponseType[AddResponseType["AlreadyAdded"] = 0] = "AlreadyAdded";
    AddResponseType[AddResponseType["Success"] = 1] = "Success";
    AddResponseType[AddResponseType["Fail"] = 2] = "Fail";
    AddResponseType[AddResponseType["Unsupported"] = 3] = "Unsupported";
})(AddResponseType = exports.AddResponseType || (exports.AddResponseType = {}));
exports.default = (function (file, filePath) {
    mkdirp_1.sync(paths_1.appDir);
    var srcPath = null;
    var homePath = process.env.HOME || '';
    switch (file) {
        case 'config':
            return AddResponseType.Unsupported;
        case 'bash_profile':
            srcPath = lodash_1.defaultTo(filePath, path.join(homePath, '.bash_profile'));
            break;
        case 'bashrc':
            srcPath = lodash_1.defaultTo(filePath, path.join(homePath, '.bashrc'));
            break;
        case 'vimrc':
            srcPath = lodash_1.defaultTo(filePath, path.join(homePath, '.vimrc'));
            break;
        case 'gitconfig':
            srcPath = lodash_1.defaultTo(filePath, path.join(homePath, '.gitconfig'));
            break;
        case 'zshrc':
            srcPath = lodash_1.defaultTo(filePath, path.join(homePath, '.zshrc'));
            break;
        default:
            if (!filePath)
                return AddResponseType.Unsupported;
            srcPath = filePath;
    }
    if (!srcPath)
        return AddResponseType.Fail;
    fs_extra_1.ensureFileSync(srcPath);
    if (fs.lstatSync(srcPath).isSymbolicLink()) {
        return AddResponseType.AlreadyAdded;
    }
    var addedFilePath = path.join(paths_1.appDir, file);
    // replace original file with symlink
    if (config.getConfig('file.createBackup'))
        fs_extra_1.copySync(srcPath, srcPath + ".bak");
    fs_extra_1.copySync(srcPath, addedFilePath);
    fs_extra_1.removeSync(srcPath);
    fs_extra_1.ensureSymlinkSync(addedFilePath, srcPath);
    // add config
    config.setConfig("path." + file, srcPath);
    return AddResponseType.Success;
});
//# sourceMappingURL=add.js.map