"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
Object.defineProperty(exports, "__esModule", { value: true });
var fs = require("fs");
var os = require("os");
var fs_extra_1 = require("fs-extra");
var mkdirp_1 = require("mkdirp");
var lodash_1 = require("lodash");
var stringify = require("json-stable-stringify");
var rc = require("rc");
var keys_1 = require("./keys");
var paths_1 = require("../paths");
var defaultConfig_1 = require("./defaultConfig");
exports.getConfigs = function () {
    var keys = [];
    for (var _i = 0; _i < arguments.length; _i++) {
        keys[_i] = arguments[_i];
    }
    var rcFile = os
        .type()
        .toLowerCase()
        .indexOf('windows') !== -1
        ? fs.existsSync(paths_1.configFile)
            ? fs_extra_1.readJsonSync(paths_1.configFile)
            : {}
        : rc(paths_1.appName);
    var config = lodash_1.omit(__assign({}, defaultConfig_1.default, rcFile), [
        '_',
        'config',
        'configs',
    ]);
    keys = keys.filter(function (k) { return !!k; });
    return keys.length ? lodash_1.pick(config, keys) : config;
};
exports.getConfig = function (key) {
    var config = exports.getConfigs(key);
    return key ? config[key] : config;
};
exports.setConfig = function (key, value) {
    var _a;
    mkdirp_1.sync(paths_1.appDir);
    var existingConfig = fs.existsSync(paths_1.configFile)
        ? fs_extra_1.readJsonSync(paths_1.configFile)
        : {};
    // Convert
    value = (function (v) {
        if (!isNaN(+v))
            return +v;
        switch (v) {
            case 'true':
                return true;
            case 'false':
                return false;
        }
        return v;
    })(value);
    if (!keys_1.validate(key, value))
        throw new Error("Invalid key value pair { '" + key + "' : " + value + " }");
    var newConfig = __assign({}, existingConfig, (_a = {}, _a[key] = value, _a));
    fs.writeFileSync(paths_1.configFile, stringify(newConfig, { space: '  ' }));
    return newConfig;
};
exports.removeConfig = function (key) {
    mkdirp_1.sync(paths_1.appDir);
    var existingConfig = fs.existsSync(paths_1.configFile)
        ? fs_extra_1.readJsonSync(paths_1.configFile)
        : {};
    var newConfig = lodash_1.omit(existingConfig, [key]);
    fs.writeFileSync(paths_1.configFile, stringify(newConfig, { space: '  ' }));
    return newConfig;
};
//# sourceMappingURL=file.js.map