"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var fs = require("fs");
var path = require("path");
var lodash_1 = require("lodash");
var stringify = require("json-stable-stringify");
var paths_1 = require("../paths");
var config_1 = require("../config");
var gist = require("../github/gist");
var version_1 = require("../version");
function getUploadingFiles() {
    var files = fs.readdirSync(paths_1.appDir).reduce(function (filesObject, file) {
        var content = fs.readFileSync(path.join(paths_1.appDir, file), 'utf8');
        filesObject[file] = {
            content: content.trim().length || content.trim() === '\n'
                ? content
                : 'EMPTY_CONTENT',
        };
        return filesObject;
    }, {});
    files.syncInfo = {
        content: stringify({
            version: version_1.default,
            lastUpdated: new Date().toISOString(),
        }) + '\n',
    };
    return files;
}
exports.getUploadingFiles = getUploadingFiles;
exports.default = (function () {
    var repoType = config_1.getConfig('repository.type');
    if (!repoType)
        throw new Error("Specify the repository type using 'icbm config set repository.type <type>'");
    switch (repoType) {
        case 'gist':
            var files_1 = getUploadingFiles();
            return gist.get(config_1.getConfig('repository.gist')).then(function (res) {
                var deleted = Object.keys(res.data.files).filter(function (f) { return !lodash_1.has(files_1, f); });
                deleted.forEach(function (f) { return (files_1[f] = null); });
                return gist.edit(files_1).then(function () {
                    return Promise.resolve({
                        uploaded: lodash_1.without.apply(void 0, [Object.keys(files_1)].concat(deleted)),
                        deleted: deleted,
                    });
                });
            });
        default:
            return Promise.reject({
                message: repoType + " is not supported yet.",
                id: 'Invalid repository type',
            });
    }
});
//# sourceMappingURL=upload.js.map